@@ -58,14 +58,13 @@ def get_insider(bin_path, config_path, logs_path):
     parser = ConfigParser()
     parser.read(insider_config_path)
 
-    store_path = parser.get('insider', 'store_path')
     redirect_api_url = parser.get('redirect', 'api_url')
     redirect_main_domain = parser.get('redirect', 'domain')
     cron_period_mins = parser.getint('cron', 'period_mins')
 
-    domain_config_path = os.path.join(store_path, 'domain.json')
-    services_config_path = os.path.join(store_path, 'services.json')
-    port_config_path = os.path.join(store_path, 'ports.json')
+    domain_config_path = os.path.join(config_path, 'domain.json')
+    services_config_path = os.path.join(config_path, 'services.json')
+    port_config_path = os.path.join(config_path, 'ports.json')
 
     port_config = config.PortConfig(port_config_path)
     upnpclient = upnpc.Upnpc()
@@ -79,4 +78,4 @@ def get_insider(bin_path, config_path, logs_path):
     return Insider(mapper, dns_service, cron_service)
 
 def get_deployed_insider():
-    return get_insider('/usr/local/bin', '/usr/local/config', '/var/log')
\ No newline at end of file
+    return get_insider('/usr/local/bin', '/etc/config', '/var/log')
\ No newline at end of file
